JS9 Archives and Catalogs Plugin

### Archives & Catalog Retrieval

The Archives & Catalog Retrieval plugin provides access to remote image and star catalog services.

Use the menus in the top left to select a data source:

- Select either Image Servers or Catalog Servers for image or catalog retrieval.
- For a given type of server, select the institution from which to retrieve.
- For a given institution, select the specific archive or catalog.

You then can fill in the RA and Dec of the target in one of three ways:

- Set the RA and Dec manually in hh:mm:ss dd:mm:ss format.
- Specify an object name in Object field and click the Set RA/Dec button to retrieve the field center.
- If an image is displayed in JS9 (and Object is blank), click the Set RA/Dec button to retrieve the field center and size from the image.

Once the RA and Dec have been filled in, pressing Retrieve Data button will start the appropriate data retrieval. Images will be loaded directly into the JS9 display. Catalogs will be loaded on top of the currently displayed image (so obviously, you need to have the appropriate image displayed in JS9 before overlaying a catalog).